searchNodes=[{"type":"module","title":"Gettext","doc":"The Gettext module provides a gettext -based API for working with internationalized applications. Basic Overview When you use Gettext, you replace hardcoded user-facing text like this: &quot;Hello world&quot; with calls like this: gettext ( &quot;Hello world&quot; ) Here, the string &quot;Hello world&quot; serves two purposes: It's displayed by default (if no translation is specified in the current language). This means that, at the very least, switching from a hardcoded string to a Gettext call is harmless. It serves as the message ID to which translations will be mapped. An example translation workflow is as follows. First, call mix gettext.extract to extract gettext() calls to .pot ( Portable Object Template ) files, which are the base for all translations. These files are templates , which means they only contain message IDs, and not actual translated strings. POT files have entries like this: #: lib/myapp_web/live/hello_live.html.heex:2 #, elixir-autogen, elixir-format msgid &quot;Hello world&quot; msgstr &quot;&quot; Then, call mix gettext.merge priv/gettext to update all locale-specific .po (Portable Object) files so that they include this message ID. Entries in PO files contain translations for their specific locale. For example, in a PO file for Italian, the entry above would look like this: #: lib/myapp_web/live/hello_live.html.heex:2 #, elixir-autogen, elixir-format msgid &quot;Hello world&quot; msgstr &quot;Ciao mondo&quot; The English string is the msgid which is used to look up the correct Italian string. That's handy, because unlike a generic key like site.greeting (as some translations systems use), the message ID tells exactly what needs to be translated. This is easier to work with for translators, for example. But it raises a question: what if you change the original English string in the code? Does that break all translations, requiring manual edits everywhere? Not necessarily. After you run mix gettext.extract again, the next mix gettext.merge can do fuzzy matching . So, if you change &quot;Hello world&quot; to &quot;Hello world!&quot; , Gettext will see that the new message ID is similar to an existing msgid , and will do two things: It will update the msgid in all .po files to match the new text. It will mark those entries as &quot;fuzzy&quot;; this hints that a (probably human) translator should check whether the Italian translation of this string needs an update. The resulting change in the .po file is this (note the &quot;fuzzy&quot; annotation): #: lib/myapp_web/live/hello_live.html.heex:2 #, elixir-autogen, elixir-format, fuzzy msgid &quot;Hello world!&quot; msgstr &quot;Ciao mondo&quot; This &quot;fuzzy matching&quot; behavior can be configured or disabled, but its existence makes updating translations to match changes in the base text easier. The rest of the documentation will cover the Gettext API in detail. Gettext API To use Gettext , a module that calls use Gettext (referred to below as a &quot;backend&quot;) has to be defined: defmodule MyApp.Gettext do use Gettext , otp_app : :my_app end This automatically defines some macros in the MyApp.Gettext backend module. Here are some examples: import MyApp.Gettext # Simple message gettext ( &quot;Here is the string to translate&quot; ) # Plural message ngettext ( &quot;Here is the string to translate&quot; , &quot;Here are the strings to translate&quot; , 3 ) # Domain-based message dgettext ( &quot;errors&quot; , &quot;Here is the error message to translate&quot; ) # Context-based message pgettext ( &quot;email&quot; , &quot;Email text to translate&quot; ) # All of the above dpngettext ( &quot;errors&quot; , &quot;context&quot; , &quot;Here is the string to translate&quot; , &quot;Here are the strings to translate&quot; , 3 ) The arguments for the Gettext macros and their order can be derived from their names. For dpgettext/4 the arguments are: domain , context , msgid , bindings (default to %{} ). Messages are looked up from .po files. In the following sections we will explore exactly what are those files before we explore the &quot;Gettext API&quot; in detail. Messages Messages are stored inside PO (Portable Object) files, with a .po extension. For example, this is a snippet from a PO file: # This is a comment msgid &quot;Hello world!&quot; msgstr &quot;Ciao mondo!&quot; PO files containing messages for an application must be stored in a directory (by default it's priv/gettext ) that has the following structure: gettext directory └ ─ locale └ ─ LC_MESSAGES ├ ─ domain_1 . po ├ ─ domain_2 . po └ ─ domain_3 . po Here, locale is the locale of the messages (for example, en_US ), LC_MESSAGES is a fixed directory, and domain_i.po are PO files containing domain-scoped messages. For more information on domains, check out the &quot;Domains&quot; section below. A concrete example of such a directory structure could look like this: priv / gettext └ ─ en_US | └ ─ LC_MESSAGES | ├ ─ default . po | └ ─ errors . po └ ─ it └ ─ LC_MESSAGES ├ ─ default . po └ ─ errors . po By default, Gettext expects messages to be stored under the priv/gettext directory of an application. This behaviour can be changed by specifying a :priv option when using Gettext : # Look for messages in my_app/priv/messages instead of # my_app/priv/gettext use Gettext , otp_app : :my_app , priv : &quot;priv/messages&quot; The messages directory specified by the :priv option should be a directory inside priv/ , otherwise some things won't work as expected. Locale At runtime, all gettext-related functions and macros that do not explicitly take a locale as an argument read the locale from the backend and fall back to Gettext's default locale. Gettext.put_locale/1 can be used to change the locale of all backends for the current Elixir process. That's the preferred mechanism for setting the locale at runtime. Gettext.put_locale/2 can be used when you want to set the locale of one specific Gettext backend without affecting other Gettext backends. Similarly, Gettext.get_locale/0 gets the locale for all backends in the current process. Gettext.get_locale/1 gets the locale of a specific backend for the current process. Check their documentation for more information. Locales are expressed as strings (like &quot;en&quot; or &quot;fr&quot; ); they can be arbitrary strings as long as they match a directory name. As mentioned above, the locale is stored per-process (in the process dictionary): this means that the locale must be set in every new process in order to have the right locale available for that process. Pay attention to this behaviour, since not setting the locale will not result in any errors when Gettext.get_locale/0 or Gettext.get_locale/1 are called; the default locale will be returned instead. To decide which locale to use, each gettext-related function in a given backend follows these steps: if there is a backend-specific locale for the given backend for this process (see put_locale/2 ), use that, otherwise if there is a global locale for this process (see put_locale/1 ), use that, otherwise if there is a backend-specific default locale in the configuration for that backend's :otp_app (see the &quot;Default locale&quot; section below), use that, otherwise use the default global Gettext locale (see the &quot;Default locale&quot; section below) Default locale The global Gettext default locale can be configured through the :default_locale key of the :gettext application: config :gettext , :default_locale , &quot;fr&quot; By default the global locale is &quot;en&quot; . See also get_locale/0 and put_locale/1 . If for some reason a backend requires a different :default_locale than all other backends, you can set the :default_locale inside the backend configuration, but this approach is generally discouraged as it makes it hard to track which locale each backend is using: config :my_app , MyApp.Gettext , default_locale : &quot;fr&quot; Gettext API There are two ways to use Gettext: using macros from your own Gettext module, like MyApp.Gettext using functions from the Gettext module These two approaches are different and each one has its own use case. Using macros Each module that calls use Gettext is usually referred to as a &quot;Gettext backend&quot;, as it implements the Gettext.Backend behaviour. When a module calls use Gettext , the following macros are automatically defined inside it: gettext/2 dgettext/3 pgettext/3 dpgettext/4 ngettext/4 dngettext/6 pngettext/6 dpngettext/6 all macros above with a _noop suffix (and without accepting bindings), for example pgettext_noop/2 Supposing the caller module is MyApp.Gettext , the macros mentioned above behave as follows: gettext(msgid, bindings \\\\ %{}) - like Gettext.gettext(MyApp.Gettext, msgid, bindings) dgettext(domain, msgid, bindings \\\\ %{}) - like Gettext.dgettext(MyApp.Gettext, domain, msgid, bindings) pgettext(msgctxt, msgid, bindings \\\\ %{}) - like Gettext.pgettext(MyApp.Gettext, msgctxt, msgid, bindings) dpgettext(domain, msgctxt, msgid, bindings \\\\ %{}) - like Gettext.dpgettext(MyApp.Gettext, domain, msgctxt, msgid, bindings) ngettext(msgid, msgid_plural, n, bindings \\\\ %{}) - like Gettext.ngettext(MyApp.Gettext, msgid, msgid_plural, n, bindings) dngettext(domain, msgid, msgid_plural, n, bindings \\\\ %{}) - like Gettext.dngettext(MyApp.Gettext, domain, msgid, msgid_plural, n, bindings) pngettext(msgctxt, msgid, msgid_plural, n, bindings \\\\ %{}) - like Gettext.pngettext(MyApp.Gettext, msgctxt, msgid, msgid_plural, n, bindings) dpngettext(domain, msgctxt, msgid, msgid_plural, n, bindings \\\\ %{}) - like Gettext.dpngettext(MyApp.Gettext, domain, msgctxt, msgid, msgid_plural, n, bindings) *_noop family of functions - used to mark messages for extraction without translating them. See the documentation for these macros in Gettext.Backend See also the Gettext.Backend behaviour for more detailed documentation about these macros. Using macros is preferred as Gettext is able to automatically sync the messages in your code with PO files. This, however, imposes a constraint: arguments passed to any of these macros have to be strings at compile time . This means that they have to be string literals or something that expands to a string literal at compile time (for example, a module attribute like @my_string &quot;foo&quot; ). These are all valid uses of the Gettext macros: Gettext . put_locale ( MyApp.Gettext , &quot;it&quot; ) MyApp.Gettext . gettext ( &quot;Hello world&quot; ) #=&gt; &quot;Ciao mondo&quot; @msgid &quot;Hello world&quot; MyApp.Gettext . gettext ( @msgid ) #=&gt; &quot;Ciao mondo&quot; The *gettext macros raise an ArgumentError exception if they receive a domain , msgctxt , msgid , or msgid_plural that doesn't expand to a string at compile time : msgid = &quot;Hello world&quot; MyApp.Gettext . gettext ( msgid ) #=&gt; ** (ArgumentError) msgid must be a string literal Using compile-time strings isn't always possible. For this reason, the Gettext module provides a set of functions as well. Using functions If compile-time strings cannot be used, the solution is to use the functions in the Gettext module instead of the macros described above. These functions perfectly mirror the macro API, but they all expect a module name as the first argument. This module has to be a module which calls use Gettext . For example: defmodule MyApp.Gettext do use Gettext , otp_app : :my_app end Gettext . put_locale ( MyApp.Gettext , &quot;pt_BR&quot; ) msgid = &quot;Hello world&quot; Gettext . gettext ( MyApp.Gettext , msgid ) #=&gt; &quot;Olá mundo&quot; While using functions from the Gettext module yields the same results as using macros (with the added benefit of dynamic arguments), all the compile-time features mentioned in the previous section are lost. Domains The dgettext and dngettext functions/macros also accept a domain as one of the arguments. The domain of a message is determined by the name of the PO file that contains that message. For example, the domain of messages in the it/LC_MESSAGES/errors.po file is &quot;errors&quot; , so those messages would need to be retrieved with dgettext or dngettext : MyApp.Gettext . dgettext ( &quot;errors&quot; , &quot;Error!&quot; ) #=&gt; &quot;Errore!&quot; When backend gettext , ngettext , or pgettext are used, the backend's default domain is used (which defaults to &quot;default&quot;). The Gettext functions accepting a backend ( gettext/3 , ngettext/5 , and pgettext/4 ) always use a domain of &quot;default&quot;. Default Domain Each backend can be configured with a specific :default_domain that replaces &quot;default&quot; in gettext/2 , pgettext/3 , and ngettext/4 for that backend. defmodule MyApp.Gettext do use Gettext , otp_app : :my_app , default_domain : &quot;messages&quot; end config :my_app , MyApp.Gettext , default_domain : &quot;messages&quot; Contexts The GNU Gettext implementation supports contexts , which are a way to contextualize messages. For example, in English, the word &quot;file&quot; could be used both as a noun as well as a verb. Contexts can be used to solve similar problems: you could have a imperative_verbs context and a nouns context as to avoid ambiguity. The functions that handle contexts have a p in their name (to match the GNU Gettext API), and are pgettext , dpgettext , pngettext , and dpngettext . The &quot;p&quot; stands for &quot;particular&quot;. Interpolation All *gettext functions and macros provided by Gettext support interpolation. Interpolation keys can be placed in msgid s or msgid_plural s with by enclosing them in %{ and } , like this: &quot;This is an %{interpolated} string&quot; Interpolation bindings can be passed as an argument to all of the *gettext functions/macros. For example, given the following PO file for the &quot;it&quot; locale: msgid &quot;Hello, %{name}!&quot; msgstr &quot;Ciao, %{name}!&quot; interpolation can be done like follows: Gettext . put_locale ( MyApp.Gettext , &quot;it&quot; ) MyApp.Gettext . gettext ( &quot;Hello, %{name}!&quot; , name : &quot;Meg&quot; ) #=&gt; &quot;Ciao, Meg!&quot; Interpolation keys that are in a string but not in the provided bindings result in an exception: MyApp.Gettext . gettext ( &quot;Hello, %{name}!&quot; ) #=&gt; ** (Gettext.MissingBindingsError) ... Keys that are in the interpolation bindings but that don't occur in the string are ignored. Interpolations in Gettext are often expanded at compile time, ensuring a low performance cost when running them at runtime. Pluralization Pluralization in Gettext for Elixir works very similar to how pluralization works in GNU Gettext. The *ngettext functions/macros accept a msgid , a msgid_plural and a count of elements; the right message is chosen based on the pluralization rule for the given locale. For example, given the following snippet of PO file for the &quot;it&quot; locale: msgid &quot;One error&quot; msgid_plural &quot;%{count} errors&quot; msgstr [ 0 ] &quot;Un errore&quot; msgstr [ 1 ] &quot;%{count} errori&quot; the ngettext macro can be used like this: Gettext . put_locale ( MyApp.Gettext , &quot;it&quot; ) MyApp.Gettext . ngettext ( &quot;One error&quot; , &quot;%{count} errors&quot; , 3 ) #=&gt; &quot;3 errori&quot; The %{count} interpolation key is a special key since it gets replaced by the number of elements argument passed to *ngettext , like if the count: 3 key-value pair were in the interpolation bindings. Hence, never pass the count key in the bindings: # `count: 4` is ignored here MyApp.Gettext . ngettext ( &quot;One error&quot; , &quot;%{count} errors&quot; , 3 , count : 4 ) #=&gt; &quot;3 errori&quot; You can specify a &quot;pluralizer&quot; module via the :plural_forms option in the configuration for each Gettext backend. defmodule MyApp.Gettext do use Gettext , otp_app : :my_app , plural_forms : MyApp.PluralForms end To learn more about pluralization rules, plural forms and what they mean to Gettext check the documentation for Gettext.Plural . Missing messages When a message is missing in the specified locale (both with functions as well as with macros), the argument is returned: in case of calls to gettext / dgettext / pgettext / dpgettext , the msgid argument is returned as is; in case of calls to ngettext / dngettext / pngettext / dpngettext , the msgid argument is returned in case of a singular value and the msgid_plural is returned in case of a plural value (following the English pluralization rule). For example: Gettext . put_locale ( MyApp.Gettext , &quot;foo&quot; ) MyApp.Gettext . gettext ( &quot;Hey there&quot; ) #=&gt; &quot;Hey there&quot; MyApp.Gettext . ngettext ( &quot;One error&quot; , &quot;%{count} errors&quot; , 3 ) #=&gt; &quot;3 errors&quot; Empty messages When a msgstr is empty ( &quot;&quot; ), the message is considered missing and the behaviour described above for missing message is applied. A plural message is considered to have an empty msgstr if at least one message in the msgstr is empty. Compile-time features As mentioned above, using the Gettext macros (as opposed to functions) allows Gettext to operate on those messages at compile-time . This can be used to extract messages from the source code into POT (Portable Object Template) files automatically (instead of having to manually add messages to POT files when they're added to the source code). The gettext.extract does exactly this: whenever there are new messages in the source code, running gettext.extract syncs the existing POT files with the changed code base. Read the documentation for Mix.Tasks.Gettext.Extract for more information on the extraction process. POT files are just template files and the messages in them do not actually contain translated strings. A POT file looks like this: # The msgstr is empty msgid &quot;hello, world&quot; msgstr &quot;&quot; Whenever a POT file changes, it's likely that developers (or translators) will want to update the corresponding PO files for each locale. To do that, gettext provides the gettext.merge Mix task. For example, running: mix gettext . merge priv / gettext -- locale pt_BR will update all the PO files in priv/gettext/pt_BR/LC_MESSAGES with the new version of the POT files in priv/gettext . Read more about the merging process in the documentation for Mix.Tasks.Gettext.Merge . Configuration :gettext configuration The :gettext application supports the following configuration options: :default_locale - a string which specifies the default global Gettext locale to use for all backends. See the &quot;Locale&quot; section for more information on backend-specific, global, and default locales. Backend configuration A Gettext backend supports some options to be configured. These options can be configured in two ways: either by passing them to use Gettext (hence at compile time): defmodule MyApp.Gettext do use Gettext , options end or by using Mix configuration, configuring the key corresponding to the backend in the configuration for your application: # For example, in config/config.exs config :my_app , MyApp.Gettext , options Note that the :otp_app option (an atom representing an OTP application) has to always be present and has to be passed to use Gettext because it's used to determine the application to read the configuration of ( :my_app in the example above); for this reason, :otp_app can't be configured via the Mix configuration. This option is also used to determine the application's directory where to search messages in. The following is a comprehensive list of supported options: :priv - a string representing a directory where messages will be searched. The directory is relative to the directory of the application specified by the :otp_app option. It is recommended to always have this directory inside &quot;priv&quot; , otherwise some features won't work as expected. By default it's &quot;priv/gettext&quot; . :plural_forms - a module which will act as a &quot;pluralizer&quot;. For more information, look at the documentation for Gettext.Plural . :default_locale - a string which specifies the default locale to use for the given backend. :split_module_by - instead of bundling all locales into a single module, this option makes Gettext build internal modules per locale, per domain, or both. This reduces compilation times and beam file sizes for large projects. For example: split_module_by: [:locale, :domain] . :split_module_compilation - control if compilation of split modules should happen in :parallel (the default) or :serial . :allowed_locales - a list of locales to bundle in the backend. Defaults to all the locales discovered in the :priv directory. This option can be useful in development to reduce compile-time by compiling only a subset of all available locales. :interpolation - the name of a module that implements the Gettext.Interpolation behaviour. Default: Gettext.Interpolation.Default Mix tasks configuration You can configure Gettext Mix tasks under the :gettext key in the configuration returned by project/0 in mix.exs : def project ( ) do [ app : :my_app , # ... gettext : [ ... ] ] end The following is a list of the supported configuration options: :fuzzy_threshold - the default threshold for the Jaro distance measuring the similarity of messages. Look at the documentation for the mix gettext.merge task ( Mix.Tasks.Gettext.Merge ) for more information on fuzzy messages. :excluded_refs_from_purging - a regex that is matched against message references. Gettext will preserve all messages in all POT files that have a matching reference. You can use this pattern to prevent Gettext from removing messages that you have extracted using another tool. :write_reference_comments - a boolean that specifies whether reference comments should be written when outputting PO(T) files. If this is false , reference comments will not be written when extracting messages or merging messages, and the ones already found in files will be discarded. :write_reference_line_numbers - a boolean that specifies whether file reference comments include line numbers when outputting PO(T) files. Defaults to true . :sort_by_msgid - modifies the sorting behavior. Can be either nil (the default), :case_sensitive , or :case_insensitive . By default or if nil , the order of existing messages in a POT file is kept and new messages are appended to the file. If :sort_by_msgid is set to :case_sensitive , existing and new messages will be mixed and sorted alphabetically by msgid. If set to :case_insensitive , the same applies but the sorting is case insensitive. Note : this option also supports true and false for backwards compatibility, but these values are deprecated as of v0.21.0. :on_obsolete - controls what happens when obsolete messages are found. If :mark_as_obsolete , messages are kept and marked as obsolete. If :delete , obsolete messages are deleted. Defaults to :delete . :store_previous_message_on_fuzzy_match - a boolean that controls whether to store the previous message text in case of a fuzzy match. Defaults to false .","ref":"Gettext.html"},{"type":"function","title":"Gettext.dgettext/4","doc":"Returns the message of the given string in the given domain. The string is translated by the backend module. The translated string is interpolated based on the bindings argument. For more information on how interpolation works, refer to the documentation of the Gettext module. If the message for the given msgid is not found, the msgid (interpolated if necessary) is returned. Examples defmodule MyApp.Gettext do use Gettext , otp_app : :my_app end Gettext . put_locale ( MyApp.Gettext , &quot;it&quot; ) Gettext . dgettext ( MyApp.Gettext , &quot;errors&quot; , &quot;Invalid&quot; ) #=&gt; &quot;Non valido&quot; Gettext . dgettext ( MyApp.Gettext , &quot;errors&quot; , &quot;%{name} is not a valid name&quot; , name : &quot;Meg&quot; ) #=&gt; &quot;Meg non è un nome valido&quot; Gettext . dgettext ( MyApp.Gettext , &quot;alerts&quot; , &quot;nonexisting&quot; ) #=&gt; &quot;nonexisting&quot;","ref":"Gettext.html#dgettext/4"},{"type":"function","title":"Gettext.dngettext/6","doc":"Returns the pluralized message of the given string in the given domain. The string is translated and pluralized by the backend module. The translated string is interpolated based on the bindings argument. For more information on how interpolation works, refer to the documentation of the Gettext module. If the message for the given msgid and msgid_plural is not found, the msgid or msgid_plural (based on n being singular or plural) is returned (interpolated if necessary). Examples defmodule MyApp.Gettext do use Gettext , otp_app : :my_app end Gettext . dngettext ( MyApp.Gettext , &quot;errors&quot; , &quot;Error&quot; , &quot;%{count} errors&quot; , 3 ) #=&gt; &quot;3 errori&quot; Gettext . dngettext ( MyApp.Gettext , &quot;errors&quot; , &quot;Error&quot; , &quot;%{count} errors&quot; , 1 ) #=&gt; &quot;Errore&quot;","ref":"Gettext.html#dngettext/6"},{"type":"function","title":"Gettext.dpgettext/5","doc":"Returns the message of the given string with a given context in the given domain. The string is translated by the backend module. The translated string is interpolated based on the bindings argument. For more information on how interpolation works, refer to the documentation of the Gettext module. If the message for the given msgid is not found, the msgid (interpolated if necessary) is returned. Examples defmodule MyApp.Gettext do use Gettext , otp_app : :my_app end Gettext . put_locale ( MyApp.Gettext , &quot;it&quot; ) Gettext . dpgettext ( MyApp.Gettext , &quot;errors&quot; , &quot;user error&quot; , &quot;Invalid&quot; ) #=&gt; &quot;Non valido&quot; Gettext . dgettext ( MyApp.Gettext , &quot;errors&quot; , &quot;signup form&quot; , &quot;%{name} is not a valid name&quot; , name : &quot;Meg&quot; ) #=&gt; &quot;Meg non è un nome valido&quot;","ref":"Gettext.html#dpgettext/5"},{"type":"function","title":"Gettext.dpngettext/7","doc":"Returns the pluralized message of the given string with a given context in the given domain. The string is translated and pluralized by the backend module. The translated string is interpolated based on the bindings argument. For more information on how interpolation works, refer to the documentation of the Gettext module. If the message for the given msgid and msgid_plural is not found, the msgid or msgid_plural (based on n being singular or plural) is returned (interpolated if necessary). Examples defmodule MyApp.Gettext do use Gettext , otp_app : :my_app end Gettext . dpngettext ( MyApp.Gettext , &quot;errors&quot; , &quot;user error&quot; , &quot;Error&quot; , &quot;%{count} errors&quot; , 3 ) #=&gt; &quot;3 errori&quot; Gettext . dpngettext ( MyApp.Gettext , &quot;errors&quot; , &quot;user error&quot; , &quot;Error&quot; , &quot;%{count} errors&quot; , 1 ) #=&gt; &quot;Errore&quot;","ref":"Gettext.html#dpngettext/7"},{"type":"function","title":"Gettext.get_locale/0","doc":"Gets the global Gettext locale for the current process. This function returns the value of the global Gettext locale for the current process. This global locale is shared between all Gettext backends; if you want backend-specific locales, see get_locale/1 and put_locale/2 . If the global Gettext locale is not set, this function returns the default global locale (configurable in the configuration for the :gettext application, see the module documentation for more information). Examples Gettext . get_locale ( ) #=&gt; &quot;en&quot;","ref":"Gettext.html#get_locale/0"},{"type":"function","title":"Gettext.get_locale/1","doc":"Gets the locale for the current process and the given backend. This function returns the value of the locale for the current process and the given backend . If there is no locale for the current process and the given backend, then either the global Gettext locale (if set), or the default locale for the given backend, or the global default locale is returned. See the &quot;Locale&quot; section in the module documentation for more information. Examples Gettext . get_locale ( MyApp.Gettext ) #=&gt; &quot;en&quot;","ref":"Gettext.html#get_locale/1"},{"type":"function","title":"Gettext.gettext/3","doc":"Returns the message of the given string in the &quot;default&quot; domain. Works exactly like: Gettext . dgettext ( backend , &quot;default&quot; , msgid , bindings )","ref":"Gettext.html#gettext/3"},{"type":"function","title":"Gettext.known_locales/1","doc":"Returns all the locales for which PO files exist for the given backend . If the messages directory for the given backend doesn't exist, then an empty list is returned. Examples With the following backend: defmodule MyApp.Gettext do use Gettext , otp_app : :my_app end and the following messages directory: my_app / priv / gettext ├ ─ en ├ ─ it └ ─ pt_BR then: Gettext . known_locales ( MyApp.Gettext ) #=&gt; [&quot;en&quot;, &quot;it&quot;, &quot;pt_BR&quot;]","ref":"Gettext.html#known_locales/1"},{"type":"function","title":"Gettext.ngettext/5","doc":"Returns the pluralized message of the given string in the &quot;default&quot; domain. Works exactly like: Gettext . dngettext ( backend , &quot;default&quot; , msgid , msgid_plural , n , bindings )","ref":"Gettext.html#ngettext/5"},{"type":"function","title":"Gettext.pgettext/4","doc":"Returns the message of the given string with the given context The string is translated by the backend module. The translated string is interpolated based on the bindings argument. For more information on how interpolation works, refer to the documentation of the Gettext module. If the message for the given msgid is not found, the msgid (interpolated if necessary) is returned. Examples defmodule MyApp.Gettext do use Gettext , otp_app : :my_app end Gettext . put_locale ( MyApp.Gettext , &quot;it&quot; ) Gettext . pgettext ( MyApp.Gettext , &quot;user-interface&quot; , &quot;Invalid&quot; ) #=&gt; &quot;Non valido&quot; Gettext . pgettext ( MyApp.Gettext , &quot;user-interface&quot; , &quot;%{name} is not a valid name&quot; , name : &quot;Meg&quot; ) #=&gt; &quot;Meg non è un nome valido&quot; Gettext . pgettext ( MyApp.Gettext , &quot;alerts-users&quot; , &quot;nonexisting&quot; ) #=&gt; &quot;nonexisting&quot;","ref":"Gettext.html#pgettext/4"},{"type":"function","title":"Gettext.pngettext/6","doc":"Returns the pluralized message of the given string with a given context in the &quot;default&quot; domain. Works exactly like: Gettext . dpngettext ( backend , &quot;default&quot; , context , msgid , msgid_plural , n , bindings )","ref":"Gettext.html#pngettext/6"},{"type":"function","title":"Gettext.put_locale/1","doc":"Sets the global Gettext locale for the current process. The locale is stored in the process dictionary. locale must be a string; if it's not, an ArgumentError exception is raised. The return value is the previous value of the current process's locale. Examples Gettext . put_locale ( &quot;pt_BR&quot; ) #=&gt; nil Gettext . get_locale ( ) #=&gt; &quot;pt_BR&quot;","ref":"Gettext.html#put_locale/1"},{"type":"function","title":"Gettext.put_locale/2","doc":"Sets the locale for the current process and the given backend . The locale is stored in the process dictionary. locale must be a string; if it's not, an ArgumentError exception is raised. The return value is the previous value of the current process's locale. Examples Gettext . put_locale ( MyApp.Gettext , &quot;pt_BR&quot; ) #=&gt; nil Gettext . get_locale ( MyApp.Gettext ) #=&gt; &quot;pt_BR&quot;","ref":"Gettext.html#put_locale/2"},{"type":"function","title":"Gettext.with_locale/2","doc":"Runs fun with the global Gettext locale set to locale . This function just sets the global Gettext locale to locale before running fun and sets it back to its previous value afterwards. Note that put_locale/2 is used to set the locale, which is thus set only for the current process (keep this in mind if you plan on spawning processes inside fun ). The value returned by this function is the return value of fun . Examples Gettext . put_locale ( &quot;fr&quot; ) MyApp.Gettext . gettext ( &quot;Hello world&quot; ) #=&gt; &quot;Bonjour monde&quot; Gettext . with_locale ( &quot;it&quot; , fn -&gt; MyApp.Gettext . gettext ( &quot;Hello world&quot; ) end ) #=&gt; &quot;Ciao mondo&quot; MyApp.Gettext . gettext ( &quot;Hello world&quot; ) #=&gt; &quot;Bonjour monde&quot;","ref":"Gettext.html#with_locale/2"},{"type":"function","title":"Gettext.with_locale/3","doc":"Runs fun with the Gettext locale set to locale for the given backend . This function just sets the Gettext locale for backend to locale before running fun and sets it back to its previous value afterwards. Note that put_locale/2 is used to set the locale, which is thus set only for the current process (keep this in mind if you plan on spawning processes inside fun ). The value returned by this function is the return value of fun . Examples Gettext . put_locale ( MyApp.Gettext , &quot;fr&quot; ) MyApp.Gettext . gettext ( &quot;Hello world&quot; ) #=&gt; &quot;Bonjour monde&quot; Gettext . with_locale ( MyApp.Gettext , &quot;it&quot; , fn -&gt; MyApp.Gettext . gettext ( &quot;Hello world&quot; ) end ) #=&gt; &quot;Ciao mondo&quot; MyApp.Gettext . gettext ( &quot;Hello world&quot; ) #=&gt; &quot;Bonjour monde&quot;","ref":"Gettext.html#with_locale/3"},{"type":"type","title":"Gettext.backend/0","doc":"","ref":"Gettext.html#t:backend/0"},{"type":"type","title":"Gettext.bindings/0","doc":"","ref":"Gettext.html#t:bindings/0"},{"type":"type","title":"Gettext.locale/0","doc":"","ref":"Gettext.html#t:locale/0"},{"type":"behaviour","title":"Gettext.Backend","doc":"Behaviour that defines the macros that a Gettext backend has to implement.","ref":"Gettext.Backend.html"},{"type":"macrocallback","title":"Gettext.Backend.dgettext/2","doc":"Same as dgettext(domain, msgid, %{}) . See also Gettext.dgettext/4 .","ref":"Gettext.Backend.html#c:dgettext/2"},{"type":"macrocallback","title":"Gettext.Backend.dgettext/3","doc":"Translates the given msgid in the given domain . bindings is a map of bindings to support interpolation. See also Gettext.dgettext/4 .","ref":"Gettext.Backend.html#c:dgettext/3"},{"type":"macrocallback","title":"Gettext.Backend.dgettext_noop/2","doc":"Marks the given message for extraction and returns it unchanged. This macro can be used to mark a message for extraction when mix gettext.extract is run. The return value is the given string, so that this macro can be used seamlessly in place of the string to extract. Examples MyApp.Gettext . dgettext_noop ( &quot;errors&quot; , &quot;Error found!&quot; ) #=&gt; &quot;Error found!&quot;","ref":"Gettext.Backend.html#c:dgettext_noop/2"},{"type":"macrocallback","title":"Gettext.Backend.dngettext/4","doc":"Same as dngettext(domain, msgid, msgid_plural, n, %{}) . See also Gettext.dngettext/6 .","ref":"Gettext.Backend.html#c:dngettext/4"},{"type":"macrocallback","title":"Gettext.Backend.dngettext/5","doc":"Translates the given plural message ( msgid + msgid_plural ) in the given domain . n is an integer used to determine how to pluralize the message. bindings is a map of bindings to support interpolation. See also Gettext.dngettext/6 .","ref":"Gettext.Backend.html#c:dngettext/5"},{"type":"macrocallback","title":"Gettext.Backend.dngettext_noop/3","doc":"Marks the given message for extraction and returns {msgid, msgid_plural} . This macro can be used to mark a message for extraction when mix gettext.extract is run. The return value of this macro is {msgid, msgid_plural} . Examples my_fun = fn { msgid , msgid_plural } -&gt; # do something with msgid and msgid_plural end my_fun . ( MyApp.Gettext . dngettext_noop ( &quot;errors&quot; , &quot;One error&quot; , &quot;%{count} errors&quot; ) )","ref":"Gettext.Backend.html#c:dngettext_noop/3"},{"type":"macrocallback","title":"Gettext.Backend.dpgettext/3","doc":"Same as dpgettext(domain, msgctxt, msgid, %{}) . See also Gettext.dpgettext/5 .","ref":"Gettext.Backend.html#c:dpgettext/3"},{"type":"macrocallback","title":"Gettext.Backend.dpgettext/4","doc":"Translates the given msgid with a given context ( msgctxt ) in the given domain . bindings is a map of bindings to support interpolation. See also Gettext.dpgettext/5 .","ref":"Gettext.Backend.html#c:dpgettext/4"},{"type":"macrocallback","title":"Gettext.Backend.dpngettext/5","doc":"Same as dpngettext(domain, msgctxt, msgid, msgid_plural, n, %{}) . See also Gettext.dpngettext/7 .","ref":"Gettext.Backend.html#c:dpngettext/5"},{"type":"macrocallback","title":"Gettext.Backend.dpngettext/6","doc":"Translates the given plural message ( msgid + msgid_plural ) with the given context ( msgctxt ) in the given domain . n is an integer used to determine how to pluralize the message. bindings is a map of bindings to support interpolation. See also Gettext.dpngettext/7 .","ref":"Gettext.Backend.html#c:dpngettext/6"},{"type":"macrocallback","title":"Gettext.Backend.gettext/1","doc":"Same as gettext(msgid, %{}) . See also Gettext.gettext/3 .","ref":"Gettext.Backend.html#c:gettext/1"},{"type":"macrocallback","title":"Gettext.Backend.gettext/2","doc":"Same as dgettext(&quot;default&quot;, msgid, %{}) , but will use a per-backend configured default domain if provided. See also Gettext.gettext/3 .","ref":"Gettext.Backend.html#c:gettext/2"},{"type":"macrocallback","title":"Gettext.Backend.gettext_comment/1","doc":"Stores an &quot;extracted comment&quot; for the next message. This macro can be used to add comments (Gettext refers to such comments as extracted comments ) to the next message that will be extracted. Extracted comments will be prefixed with #. in POT files. Calling this function multiple times will accumulate the comments; when another Gettext macro (such as gettext/2 ) is called, the comments will be extracted and attached to that message, and they will be flushed so as to start again. This macro always returns :ok . Examples MyApp.Gettext . gettext_comment ( &quot;The next message is awesome&quot; ) MyApp.Gettext . gettext_comment ( &quot;Another comment for the next message&quot; ) MyApp.Gettext . gettext ( &quot;The awesome message&quot; )","ref":"Gettext.Backend.html#c:gettext_comment/1"},{"type":"macrocallback","title":"Gettext.Backend.gettext_noop/1","doc":"Same as dgettext_noop(&quot;default&quot;, msgid) .","ref":"Gettext.Backend.html#c:gettext_noop/1"},{"type":"callback","title":"Gettext.Backend.handle_missing_bindings/2","doc":"Default handling for missing bindings. This function is called when there are missing bindings in a message. It takes a Gettext.MissingBindingsError struct and the message with the wrong bindings left as is with the %{} syntax. For example, if something like this is called: MyApp.Gettext . gettext ( &quot;Hello %{name}, your favorite color is %{color}&quot; , name : &quot;Jane&quot; , color : &quot;blue&quot; ) and our it/LC_MESSAGES/default.po looks like this: msgid &quot;Hello %{name}, your favorite color is %{color}&quot; msgstr &quot;Ciao %{name}, il tuo colore preferito è %{colour}&quot; # (typo) then Gettext will call: MyApp.Gettext . handle_missing_bindings ( exception , &quot;Ciao Jane, il tuo colore preferito è %{colour}&quot; ) where exception is a struct that looks like this: % Gettext.MissingBindingsError { backend : MyApp.Gettext , domain : &quot;default&quot; , locale : &quot;it&quot; , msgid : &quot;Ciao %{name}, il tuo colore preferito è %{colour}&quot; , bindings : [ :colour ] , } The return value of the handle_missing_bindings/2 callback is used as the translated string that the message macros and functions return. The default implementation for this function uses Logger.error/1 to warn about the missing binding and returns the translated message with the incomplete bindings. This function can be overridden. For example, to raise when there are missing bindings: def handle_missing_bindings ( exception , _incomplete ) do raise exception end","ref":"Gettext.Backend.html#c:handle_missing_bindings/2"},{"type":"callback","title":"Gettext.Backend.handle_missing_plural_translation/7","doc":"Default handling for plural messages with a missing message. Same as handle_missing_translation/5 , but for plural messages. In this case, n is the number used for pluralizing the translated string. Earlier versions of this library provided a callback without msgctxt. Users implementing that callback will still get the same results, but they are encouraged to switch to the new 7-argument version.","ref":"Gettext.Backend.html#c:handle_missing_plural_translation/7"},{"type":"callback","title":"Gettext.Backend.handle_missing_translation/5","doc":"Default handling for messages with a missing message. When a Gettext function/macro is called with a string to translate into a locale but that locale doesn't provide a message for that string, this callback is invoked. msgid is the string that Gettext tried to translate. This function should return {:ok, translated} if a message can be fetched or constructed for the given string. If you cannot find a message, it should return {:default, translated} , where the translated string defaults to the interpolated msgid. You can, however, customize the default to, for example, pick the message from the default locale. The important is to return :default instead of :ok whenever the result does not quite match the requested locale. Earlier versions of this library provided a callback without msgctxt. Users implementing that callback will still get the same results, but they are encouraged to switch to the new 5-argument version.","ref":"Gettext.Backend.html#c:handle_missing_translation/5"},{"type":"macrocallback","title":"Gettext.Backend.ngettext/3","doc":"Same as ngettext(msgid, msgid_plural, n, %{}) . See also Gettext.ngettext/5 .","ref":"Gettext.Backend.html#c:ngettext/3"},{"type":"macrocallback","title":"Gettext.Backend.ngettext/4","doc":"Same as dngettext(&quot;default&quot;, msgid, msgid_plural, n, bindings) , but will use a per-backend configured default domain if provided. See also Gettext.ngettext/5 .","ref":"Gettext.Backend.html#c:ngettext/4"},{"type":"macrocallback","title":"Gettext.Backend.ngettext_noop/2","doc":"Same as dngettext_noop(&quot;default&quot;, msgid, mgsid_plural) , but will use a per-backend configured default domain if provided.","ref":"Gettext.Backend.html#c:ngettext_noop/2"},{"type":"macrocallback","title":"Gettext.Backend.pgettext/2","doc":"Same as pgettext(msgctxt, msgid, %{}) . See also Gettext.pgettext/4 .","ref":"Gettext.Backend.html#c:pgettext/2"},{"type":"macrocallback","title":"Gettext.Backend.pgettext/3","doc":"Translates the given msgid with the given context ( msgctxt ). bindings is a map of bindings to support interpolation. See also Gettext.pgettext/4 .","ref":"Gettext.Backend.html#c:pgettext/3"},{"type":"macrocallback","title":"Gettext.Backend.pngettext/4","doc":"Same as pngettext(msgctxt, msgid, msgid_plural, n, %{}) . See also Gettext.pngettext/6 .","ref":"Gettext.Backend.html#c:pngettext/4"},{"type":"macrocallback","title":"Gettext.Backend.pngettext/5","doc":"Translates the given plural message ( msgid + msgid_plural ) with the given context ( msgctxt ). n is an integer used to determine how to pluralize the message. bindings is a map of bindings to support interpolation. See also Gettext.pngettext/6 .","ref":"Gettext.Backend.html#c:pngettext/5"},{"type":"behaviour","title":"Gettext.Interpolation","doc":"Behaviour to provide Gettext string interpolation. By default, Gettext uses Gettext.Interpolation.Default as the interpolation module.","ref":"Gettext.Interpolation.html"},{"type":"macrocallback","title":"Gettext.Interpolation.compile_interpolate/3","doc":"Called to perform interpolation at compile time .","ref":"Gettext.Interpolation.html#c:compile_interpolate/3"},{"type":"callback","title":"Gettext.Interpolation.message_format/0","doc":"Defines the Gettext message format to be used when extracting. The default interpolation module that ships with Gettext uses &quot;elixir-format&quot; . See the GNU Gettext documentation .","ref":"Gettext.Interpolation.html#c:message_format/0"},{"type":"callback","title":"Gettext.Interpolation.runtime_interpolate/2","doc":"Called to perform interpolation at runtime . If successful, should return {:ok, interpolated_string} . If there are missing bindings, should return {:missing_bindings, partially_interpolated, missing} where partially_interpolated is a string with the available bindings interpolated.","ref":"Gettext.Interpolation.html#c:runtime_interpolate/2"},{"type":"type","title":"Gettext.Interpolation.bindings/0","doc":"","ref":"Gettext.Interpolation.html#t:bindings/0"},{"type":"type","title":"Gettext.Interpolation.translation_type/0","doc":"","ref":"Gettext.Interpolation.html#t:translation_type/0"},{"type":"module","title":"Gettext.Interpolation.Default","doc":"Default implementation for the Gettext.Interpolation behaviour. Replaces %{binding_name} with the string value of the binding_name binding.","ref":"Gettext.Interpolation.Default.html"},{"type":"macro","title":"Gettext.Interpolation.Default.compile_interpolate/3","doc":"Compiles a static message to interpolate with dynamic bindings. Implementation of the Gettext.Interpolation.compile_interpolate/3 macro callback. Takes a static message and some dynamic bindings. The generated code will return an {:ok, interpolated_string} tuple if the interpolation is successful. If it encounters a binding in the message that is missing from bindings , it returns {:missing_bindings, incomplete_string, missing_bindings} , where incomplete_string is the string with only the present bindings interpolated and missing_bindings is a list of atoms representing bindings that are in interpolatable but not in bindings .","ref":"Gettext.Interpolation.Default.html#compile_interpolate/3"},{"type":"function","title":"Gettext.Interpolation.Default.message_format/0","doc":"Implementation of Gettext.Interpolation.message_format/0 . Examples iex&gt; Gettext.Interpolation.Default . message_format ( ) &quot;elixir-format&quot;","ref":"Gettext.Interpolation.Default.html#message_format/0"},{"type":"function","title":"Gettext.Interpolation.Default.runtime_interpolate/2","doc":"Interpolate a message or interpolatable with the given bindings. Implementation of the Gettext.Interpolation.runtime_interpolate/2 callback. This function takes a message and some bindings and returns an {:ok, interpolated_string} tuple if interpolation is successful. If it encounters a binding in the message that is missing from bindings , it returns {:missing_bindings, incomplete_string, missing_bindings} where incomplete_string is the string with only the present bindings interpolated and missing_bindings is a list of atoms representing bindings that are in interpolatable but not in bindings . Examples iex&gt; msgid = &quot;Hello %{name}, you have %{count} unread messages&quot; iex&gt; good_bindings = %{ name : &quot;José&quot; , count : 3 } iex&gt; Gettext.Interpolation.Default . runtime_interpolate ( msgid , good_bindings ) { :ok , &quot;Hello José, you have 3 unread messages&quot; } iex&gt; Gettext.Interpolation.Default . runtime_interpolate ( msgid , %{ name : &quot;José&quot; } ) { :missing_bindings , &quot;Hello José, you have %{count} unread messages&quot; , [ :count ] } iex&gt; msgid = &quot;Hello %{name}, you have %{count} unread messages&quot; iex&gt; interpolatable = Gettext.Interpolation.Default . to_interpolatable ( msgid ) iex&gt; good_bindings = %{ name : &quot;José&quot; , count : 3 } iex&gt; Gettext.Interpolation.Default . runtime_interpolate ( interpolatable , good_bindings ) { :ok , &quot;Hello José, you have 3 unread messages&quot; } iex&gt; Gettext.Interpolation.Default . runtime_interpolate ( interpolatable , %{ name : &quot;José&quot; } ) { :missing_bindings , &quot;Hello José, you have %{count} unread messages&quot; , [ :count ] }","ref":"Gettext.Interpolation.Default.html#runtime_interpolate/2"},{"type":"type","title":"Gettext.Interpolation.Default.interpolatable/0","doc":"Something that can be interpolated. It's either a string (a literal) or an atom (representing a binding name).","ref":"Gettext.Interpolation.Default.html#t:interpolatable/0"},{"type":"behaviour","title":"Gettext.Plural","doc":"Behaviour and default implementation for finding plural forms in given locales. This module both defines the Gettext.Plural behaviour and provides a default implementation for it. Plural Forms For a given language, there is a grammatical rule on how to change words depending on the number qualifying the word. Different languages can have different rules. [source] Such grammatical rules define a number of plural forms . For example, English has two plural forms: one for when there is just one element (the singular ) and another one for when there are zero or more than one elements (the plural ). There are languages which only have one plural form and there are languages which have more than two. In GNU Gettext (and in Gettext for Elixir), plural forms are represented by increasing 0-indexed integers. For example, in English 0 means singular and 1 means plural. The goal of this module is to determine, given a locale: how many plural forms exist in that locale ( nplurals/1 ); to what plural form a given number of elements belongs to in that locale ( plural/2 ). Default Implementation Gettext.Plural provides a default implementation of a plural module. Most common languages used on Earth should be covered by this default implementation. If custom pluralization rules are needed (for example, to add additional languages) a different plural module can be specified when creating a Gettext backend. For example, pluralization rules for the Elvish language could be added as follows: defmodule MyApp.Plural do @behaviour Gettext.Plural def nplurals ( &quot;elv&quot; ) , do : 3 def plural ( &quot;elv&quot; , 0 ) , do : 0 def plural ( &quot;elv&quot; , 1 ) , do : 1 def plural ( &quot;elv&quot; , _ ) , do : 2 # Fall back to Gettext.Plural defdelegate nplurals ( locale ) , to : Gettext.Plural defdelegate plural ( locale , n ) , to : Gettext.Plural end The mathematical expressions used in this module to determine the plural form of a given number of elements are taken from this page as well as from Mozilla's guide on &quot;Localization and plurals&quot; . Changing Implementations Once you have defined your custom plural forms module, you can use it in two ways. You can set it for all Gettext backends in your configuration: # For example, in config/config.exs config :gettext , :plural_forms , MyApp.Plural or you can set it for each specific backend when you call use Gettext : defmodule MyApp.Gettext do use Gettext , otp_app : :my_app , plural_forms : MyApp.Plural end Compile-time Configuration Set :plural_forms in your config/config.exs and not in config/runtime.exs , as Gettext reads this option when compiling your backends. Task such as mix gettext.merge use the plural backend configured under the :gettext application, so in general the global configuration approach is preferred. Some tasks also allow the number of plural forms to be given explicitly, for example: mix gettext . merge priv / gettext -- locale = gsw_CH -- plural - forms = 2 Unknown Locales Trying to call Gettext.Plural functions with unknown locales will result in a Gettext.Plural.UnknownLocaleError exception. Language and Territory Often, a locale is composed as a language and territory pair, such as en_US . The default implementation for Gettext.Plural handles xx_YY by forwarding it to xx (except for just Brazilian Portuguese , pt_BR , which is not forwarded to pt as pluralization rules differ slightly). We treat the underscore as a separator according to ISO 15897 . Sometimes, a dash - is used as a separator (for example BCP47 locales use this as in en-US ): this is not forwarded to en in the default Gettext.Plural (and it will raise an Gettext.Plural.UnknownLocaleError exception if there are no messages for en-US ). We recommend defining a custom plural forms module that replaces - with _ if needed. Examples An example of the plural form of a given number of elements in the Polish language: iex&gt; Gettext.Plural . plural ( &quot;pl&quot; , 1 ) 0 iex&gt; Gettext.Plural . plural ( &quot;pl&quot; , 2 ) 1 iex&gt; Gettext.Plural . plural ( &quot;pl&quot; , 5 ) 2 iex&gt; Gettext.Plural . plural ( &quot;pl&quot; , 112 ) 2 As expected, nplurals/1 returns the possible number of plural forms: iex&gt; Gettext.Plural . nplurals ( &quot;pl&quot; ) 3","ref":"Gettext.Plural.html"},{"type":"callback","title":"Gettext.Plural.init/1","doc":"Should initialize the context for nplurals/1 and plural/2 . This callback should perform all preparations for the provided locale, which is part of the pluralization context (see pluralization_context/0 ). For example, you can use this callback to parse the Plural-Forms header and determine pluralization rules for the locale. If defined, Gettext calls this callback once at compile time. If not defined, the returned plural_info will be equals to the locale found in pluralization_context . Examples defmodule MyApp.Plural do @behaviour Gettext.Plural @impl true def init ( %{ locale : _locale , plural_forms_header : header } ) do { nplurals , rule } = parse_plural_forms_header ( header ) # This is what other callbacks can use to determine the plural. { nplurals , rule } end @impl true def nplurals ( { _locale , nplurals , _rule } ) , do : nplurals # ... end","ref":"Gettext.Plural.html#c:init/1"},{"type":"function","title":"Gettext.Plural.nplurals/1","doc":"Default implementation of the nplurals/1 callback.","ref":"Gettext.Plural.html#nplurals/1"},{"type":"callback","title":"Gettext.Plural.nplurals/1","doc":"Should return the number of possible plural forms in the given locale .","ref":"Gettext.Plural.html#c:nplurals/1"},{"type":"function","title":"Gettext.Plural.plural/2","doc":"Default implementation of the plural/2 callback.","ref":"Gettext.Plural.html#plural/2"},{"type":"callback","title":"Gettext.Plural.plural/2","doc":"Should return the plural form in the given locale for the given count of elements.","ref":"Gettext.Plural.html#c:plural/2"},{"type":"function","title":"Gettext.Plural.plural_forms_header/1","doc":"","ref":"Gettext.Plural.html#plural_forms_header/1"},{"type":"callback","title":"Gettext.Plural.plural_forms_header/1","doc":"Should return the value of the Plural-Forms header for the given locale , if present. If the value of the Plural-Forms header is unavailable for any reason, this function should return nil . This callback is optional. If it's not defined, the fallback returns: &quot;nplurals={nplurals};&quot;","ref":"Gettext.Plural.html#c:plural_forms_header/1"},{"type":"type","title":"Gettext.Plural.locale/0","doc":"A locale passed to plural/2 .","ref":"Gettext.Plural.html#t:locale/0"},{"type":"type","title":"Gettext.Plural.plural_info/0","doc":"The term that the optional init/1 callback returns.","ref":"Gettext.Plural.html#t:plural_info/0"},{"type":"type","title":"Gettext.Plural.pluralization_context/0","doc":"The context passed to the optional init/1 callback. If :plural_forms_header is present, it contains the contents of the Plural-Forms Gettext header.","ref":"Gettext.Plural.html#t:pluralization_context/0"},{"type":"task","title":"Mix.Tasks.Gettext.Extract","doc":"Extracts messages by recompiling the Elixir source code. mix gettext.extract [OPTIONS] messages are extracted into POT (Portable Object Template) files with a .pot extension. The location of these files is determined by the :otp_app and :priv options given by Gettext modules when they call use Gettext . One POT file is generated for each message domain. All automatically-extracted messages are assigned the elixir-autogen flag. If a message from the POT is no longer present and has the elixir-autogen flag, the message is removed. Before v0.19.0 , the elixir-format flag was used to detect automatically extracted messages. This has been deprecated in v0.19.0 . When extracting with the newest version, the new elixir-autogen flag is added to all automatically extracted messages. All messages are assigned a format flag. When using the default interpolation module, that flag is elixir-format . With other interpolation modules, the flag name is defined by that implementation (see Gettext.Interpolation.message_format/0 ). If you would like to verify that your POT files are up to date with the current state of the codebase, you can provide the --check-up-to-date flag. This is particularly useful for automated checks and in CI systems. This validation will fail even when the same calls to Gettext only change location in the codebase: mix gettext.extract --check-up-to-date It is possible to pass the --merge option to perform merging for every Gettext backend updated during merge: mix gettext.extract --merge All other options passed to gettext.extract are forwarded to the gettext.merge task ( Mix.Tasks.Gettext.Merge ), which is called internally by this task. For example: mix gettext.extract --merge --no-fuzzy","ref":"Mix.Tasks.Gettext.Extract.html"},{"type":"task","title":"Mix.Tasks.Gettext.Merge","doc":"Merges PO/POT files with PO files. This task is used when messages in the source code change: when they do, mix gettext.extract is usually used to extract the new messages to POT files. At this point, developers or translators can use this task to &quot;sync&quot; the newly-updated POT files with the existing locale-specific PO files. All the metadata for each message (like position in the source code, comments, and so on) is taken from the newly-updated POT file; the only things taken from the PO file are the actual translated strings. Fuzzy Matching Messages in the updated PO/POT file that have an exact match (a message with the same msgid ) in the old PO file are merged as described above. When a message in the updated PO/POT files has no match in the old PO file, Gettext attemps a fuzzy match for that message. For example, imagine we have this POT file: msgid &quot;hello, world!&quot; msgstr &quot;&quot; and we merge it with this PO file: # No exclamation point here in the msgid msgid &quot;hello, world&quot; msgstr &quot;ciao, mondo&quot; Since the two messages are similar, Gettext takes the msgstr from the existing message over to the new message, which it however marks as fuzzy : #, fuzzy msgid &quot;hello, world!&quot; msgstr &quot;ciao, mondo&quot; Generally, a fuzzy flag calls for review from a translator. Fuzzy matching can be configured (for example, the threshold for message similarity can be tweaked) or disabled entirely. Look at the &quot;Options&quot; section . Usage mix gettext.merge OLD_FILE UPDATED_FILE [OPTIONS] mix gettext.merge DIR [OPTIONS] If two files are given as arguments, OLD_FILE must be a .po file and UPDATE_FILE must be a .po / .pot file. The first one is the old PO file, while the second one is the last generated one. They are merged and written over the first file. For example: mix gettext.merge priv/gettext/en/LC_MESSAGES/default.po priv/gettext/default.pot If only one argument is given, then that argument must be a directory containing Gettext messages (with .pot files at the root level alongside locale directories - this is usually a &quot;backend&quot; directory used by a Gettext backend, see Gettext.Backend ). For example: mix gettext.merge priv/gettext If the --locale LOCALE option is given, then only the PO files in &lt;DIR&gt;/&lt;LOCALE&gt;/LC_MESSAGES will be merged with the POT files in DIR . If no options are given, then all the PO files for all locales under DIR are merged with the POT files in DIR . Plural Forms By default, Gettext will determine the number of plural forms for newly-generated messages by checking the value of nplurals in the Plural-Forms header in the existing .po file. If a .po file doesn't already exist and Gettext is creating a new one or if the Plural-Forms header is not in the .po file, Gettext will use the number of plural forms that the plural module (see Gettext.Plural ) returns for the locale of the file being created. The content of the Plural-Forms header can be forced through the --plural-forms-header option (see below). Options --locale - a string representing a locale. If this is provided, then only the PO files in &lt;DIR&gt;/&lt;LOCALE&gt;/LC_MESSAGES will be merged with the POT files in DIR . This option can only be given when a single argument is passed to the task (a directory). --no-fuzzy - don't perform fuzzy matching when merging files. --fuzzy-threshold - a float between 0 and 1 which represents the minimum Jaro distance needed for two messages to be considered a fuzzy match. Overrides the global :fuzzy_threshold option (see the docs for Gettext for more information on this option). --plural-forms - ( deprecated in v0.22.0 ) an integer strictly greater than 0 . If this is passed, new messages in the target PO files will have this number of empty plural forms. This is deprecated in favor of passing the --plural-forms-header , which contains the whole plural-forms specification. See the &quot;Plural forms&quot; section above. --plural-forms-header - the content of the Plural-Forms header as a string. If this is passed, new messages in the target PO files will use this content to determine the number of plurals. See the &quot;Plural Forms&quot; section . --on-obsolete - controls what happens when obsolete messages are found. If mark_as_obsolete , messages are kept and marked as obsolete. If delete , obsolete messages are deleted. Defaults to delete . --store-previous-message-on-fuzzy-match - controls if the previous messages are recorded on fuzzy matches. Is off by default.","ref":"Mix.Tasks.Gettext.Merge.html"},{"type":"function","title":"Mix.Tasks.Gettext.Merge.locale_dir/2","doc":"","ref":"Mix.Tasks.Gettext.Merge.html#locale_dir/2"},{"type":"exception","title":"Gettext.Error","doc":"A generic error raised for a variety of possible Gettext-related reasons.","ref":"Gettext.Error.html"},{"type":"type","title":"Gettext.Error.t/0","doc":"","ref":"Gettext.Error.html#t:t/0"},{"type":"exception","title":"Gettext.MissingBindingsError","doc":"An error message raised for missing bindings errors.","ref":"Gettext.MissingBindingsError.html"},{"type":"type","title":"Gettext.MissingBindingsError.t/0","doc":"","ref":"Gettext.MissingBindingsError.html#t:t/0"},{"type":"exception","title":"Gettext.Plural.UnknownLocaleError","doc":"Raised when a pluralized module doesn't know how to handle a locale. Examples raise Gettext.Plural.UnknownLocaleError , &quot;en-US&quot;","ref":"Gettext.Plural.UnknownLocaleError.html"},{"type":"exception","title":"Gettext.PluralFormError","doc":"An generic error for when a plural form is missing for a given locale.","ref":"Gettext.PluralFormError.html"},{"type":"type","title":"Gettext.PluralFormError.t/0","doc":"","ref":"Gettext.PluralFormError.html#t:t/0"}]